#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 safe-exceptions
version:              0.1.7.4
visibility:           public
id:                   safe-exceptions-0.1.7.4-LLCsXRZv4m2CGwiR6DBSct
key:                  safe-exceptions-0.1.7.4-LLCsXRZv4m2CGwiR6DBSct
license:              MIT
copyright:            2016 FP Complete
maintainer:           michael@fpcomplete.com
author:               Michael Snoyman
homepage:             https://github.com/fpco/safe-exceptions#readme
synopsis:             Safe, consistent, and easy exception handling
description:          Please see README.md
category:             Control
abi:                  2e3890f08187e85a49a5c4d7852aaeae
exposed:              True
exposed-modules:      Control.Exception.Safe
import-dirs:          /usr/lib/ghc-9.6.6/site-local/safe-exceptions-0.1.7.4
library-dirs:         /usr/lib/ghc-9.6.6/site-local/safe-exceptions-0.1.7.4
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/safe-exceptions-0.1.7.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-safe-exceptions
hs-libraries:         HSsafe-exceptions-0.1.7.4-LLCsXRZv4m2CGwiR6DBSct
depends:
    base-4.18.2.1 deepseq-1.4.8.1 exceptions-0.10.7
    transformers-0.6.1.0

haddock-interfaces:
    /usr/share/doc/haskell-safe-exceptions/html/safe-exceptions.haddock

haddock-html:         /usr/share/doc/haskell-safe-exceptions/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

